@@ -19,14 +19,13 @@ from sqlalchemy import orm
 from sqlalchemy.orm import exc
 from sqlalchemy import sql
 
+from neutron_lib.db import model_base
 from neutron_lib import exceptions as n_exc
 from oslo_log import helpers as log_helpers
 from oslo_utils import uuidutils
 
 from neutron import context as n_context
 from neutron.db import common_db_mixin
-from neutron.db import model_base
-from neutron.db import models_v2
 
 from networking_sfc._i18n import _
 
@@ -40,7 +39,7 @@ class NodeNotFound(n_exc.NotFound):
 
 
 # name changed to ChainPathId
-class UuidIntidAssoc(model_base.BASEV2, models_v2.HasId):
+class UuidIntidAssoc(model_base.BASEV2, model_base.HasId):
     __tablename__ = 'sfc_uuid_intid_associations'
     uuid = sa.Column(sa.String(36), primary_key=True)
     intid = sa.Column(sa.Integer, unique=True, nullable=False)
@@ -65,7 +64,7 @@ def singleton(class_):
 @singleton
 class IDAllocation(object):
     def __init__(self, context):
-        # Get the inital range from conf file.
+        # Get the initial range from conf file.
         conf_obj = {'group': [1, 255], 'portchain': [256, 65536]}
         self.conf_obj = conf_obj
         self.session = context.session
@@ -133,8 +132,8 @@ class PathPortAssoc(model_base.BASEV2):
     weight = sa.Column(sa.Integer, nullable=False, default=1)
 
 
-class PortPairDetail(model_base.BASEV2, models_v2.HasId,
-                     models_v2.HasTenant):
+class PortPairDetail(model_base.BASEV2, model_base.HasId,
+                     model_base.HasProject):
     __tablename__ = 'sfc_portpair_details'
     ingress = sa.Column(sa.String(36), nullable=True)
     egress = sa.Column(sa.String(36), nullable=True)
@@ -149,7 +148,7 @@ class PortPairDetail(model_base.BASEV2, models_v2.HasId,
                                   cascade='all,delete')
 
 
-class PathNode(model_base.BASEV2, models_v2.HasId, models_v2.HasTenant):
+class PathNode(model_base.BASEV2, model_base.HasId, model_base.HasProject):
     __tablename__ = 'sfc_path_nodes'
     nsp = sa.Column(sa.Integer, nullable=False)
     nsi = sa.Column(sa.Integer, nullable=False)
